# Chert Default Theme

This is the Chert default theme, originally created for
[sedimental.org](http://sedimental.org). The code is BSD-licensed, so
definitely customize it and leave a note
[here](http://github.com/mahmoud/chert/issues) when your modifications
are publicly visible! Always love a new site theme.
